summaryrefslogtreecommitdiff
path: root/indra/newview/llviewerfloaterreg.cpp
diff options
context:
space:
mode:
authorDave Parks <davep@lindenlab.com>2011-07-18 23:50:50 -0500
committerDave Parks <davep@lindenlab.com>2011-07-18 23:50:50 -0500
commit7ef1550fbb01acfb0cba0e849f1933462612784a (patch)
treedde820baa0134031d46b0c117ad34545d9e8cfe9 /indra/newview/llviewerfloaterreg.cpp
parent4dc0850da7469906e5ad052da71830b05005295b (diff)
parente8b71e0585ab126f9e77da93d6830a1a73a7aa92 (diff)
merge
Diffstat (limited to 'indra/newview/llviewerfloaterreg.cpp')
-rw-r--r--indra/newview/llviewerfloaterreg.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llviewerfloaterreg.cpp b/indra/newview/llviewerfloaterreg.cpp
index 6ae8e79be4..26f05337a4 100644
--- a/indra/newview/llviewerfloaterreg.cpp
+++ b/indra/newview/llviewerfloaterreg.cpp
@@ -130,12 +130,12 @@
// *NOTE: Please add files in alphabetical order to keep merges easy.
// handle secondlife:///app/floater/{NAME} URLs
class LLFloaterOpenHandler : public LLCommandHandler
{
public:
// requires trusted browser to trigger
- LLFloaterOpenHandler() : LLCommandHandler("floater", UNTRUSTED_THROTTLE) { }
+ LLFloaterOpenHandler() : LLCommandHandler("openfloater", UNTRUSTED_THROTTLE) { }
bool handle(const LLSD& params, const LLSD& query_map,
LLMediaCtrl* web)
@@ -130,12 +130,12 @@
// *NOTE: Please add files in alphabetical order to keep merges easy.
-// handle secondlife:///app/floater/{NAME} URLs
+// handle secondlife:///app/openfloater/{NAME} URLs
class LLFloaterOpenHandler : public LLCommandHandler
{